# Introduction

This project mostly expands the idea of a skikit-learn pipeline to accept bivariate pipelines,
this makes it much easier to make a single pipeline with all aspects of feature
engineering and supervised training, and this in turn makes it much easier to
support the creation of walk-forward trained-models.

For more information on the aika project see the [aika webpage](https://github.com/phil20686/aika/)

# Installation
``python -m pip install aika-ml``